@@ -12,6 +12,9 @@ from ploomber.env.EnvDict import EnvDict
 class Env:
     """Return the current environment
 
+    NOTE: this API is experimental and subject to change, it is recommmended
+    to use @with_env and @load_env decorators instead
+
     Env provides a clean and consistent way of managing environment and
     configuration settings. Its simplest usage provides access to settings
     specified via an `env.yaml`.
@@ -117,7 +120,7 @@ class Env:
     def __repr__(self):
         s = 'Env({})'.format(str(self._data))
         if self._path_to_env:
-            s += 'loaded from ' + self._path_to_env
+            s += ' (from %s)' % str(self._path_to_env)
         return s
 
     def __dir__(self):
