@@ -129,7 +129,6 @@ class Parallel(Executor):
             set_done = set([t.name for t in done])
 
             if not self._i % 1000:
-                print('done ', set_done, 'set all', set_all)
                 self._logger.debug('Finished tasks so far: %s', set_done)
                 self._logger.debug('Remaining tasks: %s',
                                    set_all - set_done)
@@ -164,14 +163,15 @@ class Parallel(Executor):
         exps = ExceptionCollector([get_future_result(f, future_mapping)
                                    for f, t
                                    in future_mapping.items()
-                                   if isinstance(get_future_result(f, future_mapping),
+                                   if isinstance(get_future_result(f,
+                                                 future_mapping),
                                                  ExceptionResult)])
 
         if exps:
             raise DAGBuildError('DAG build failed, the following '
                                 'tasks crashed '
-                                '(corresponding tasks aborted '
-                                'execuion):\n{}'
+                                '(corresponding downstream tasks aborted '
+                                'execution):\n{}'
                                 .format(str(exps)))
 
     # __getstate__ and __setstate__ are needed to make this picklable
